@@ -100,11 +100,14 @@ class QMLScreen : public QQuickItem
   private:
     void qmlOutputMoved(QMLOutput *qmlOutput);
     void updateCornerOutputs();
+    void setOutputScale(float scale);
 
     KScreen::ConfigPtr m_config;
     QHash<KScreen::OutputPtr,QMLOutput*> m_outputMap;
+    QVector<QMLOutput*> m_manuallyMovedOutputs;
     int m_connectedOutputsCount = 0;
     int m_enabledOutputsCount = 0;
+    float m_outputScale = 1.0 / 8.0;
 
     QMLOutput *m_leftmost = nullptr;
     QMLOutput *m_topmost = nullptr;
